pub struct Weights { /* private fields */ }Expand description
Container for all loaded RWKV7 model weights.
Implementations
Sourceimpl Weights
impl Weights
Sourcepub fn load<P: AsRef<Path>>(path: P) -> Result<Self>
pub fn load<P: AsRef<Path>>(path: P) -> Result<Self>
Load weights from a safetensors file.
This function:
- Reads and parses the JSON header to extract tensor metadata
- Loads each tensor’s FP32 data into memory
- Returns a Weights container for efficient tensor lookup
Sourcepub fn get(&self, name: &str) -> Option<&WeightTensor>
pub fn get(&self, name: &str) -> Option<&WeightTensor>
Get a tensor by name, returning None if not found.
Sourcepub fn require(&self, name: &str) -> Result<&WeightTensor>
pub fn require(&self, name: &str) -> Result<&WeightTensor>
Get a tensor by name, or return an error if not found.
Sourcepub fn tensor_names(&self) -> impl Iterator<Item = &str>
pub fn tensor_names(&self) -> impl Iterator<Item = &str>
Iterate over all tensor names.
Sourcepub fn print_summary(&self)
pub fn print_summary(&self)
Print summary of all loaded tensors (for debugging).